"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebNativeAuthClient = void 0;
const utils_1 = require("@8base/utils");
const graphql_request_1 = require("graphql-request");
const jwt_decode_1 = __importDefault(require("jwt-decode"));
const R = __importStar(require("ramda"));
const isEmptyOrNil = R.either(R.isNil, R.isEmpty);
const USER_LOGIN_MUTATION = graphql_request_1.gql `
  mutation Login($data: UserLoginInput!) {
    userLogin(data: $data) {
      success
      auth {
        idToken
        refreshToken
      }
    }
  }
`;
const REFRESH_TOKEN_MUTATION = graphql_request_1.gql `
  mutation RefreshToken($data: RefreshTokenInput!) {
    userRefreshToken(data: $data) {
      refreshToken
      idToken
    }
  }
`;
/**
 * Creates instance of the web native auth client.
 */
class WebNativeAuthClient {
    constructor(options, storageOptions = {}) {
        utils_1.throwIfMissingRequiredParameters(['authProfileId', 'apiEndpoint'], utils_1.PACKAGES.WEB_AUTH0_AUTH_CLIENT, options);
        const { authProfileId, apiEndpoint } = options;
        this.storageAPI = new utils_1.StorageAPI(storageOptions.storage || window.localStorage, storageOptions.storageKey || 'auth', storageOptions.initialState);
        this.authProfileId = authProfileId;
        this.graphQLClient = new graphql_request_1.GraphQLClient(apiEndpoint);
    }
    setState(state) {
        this.storageAPI.setState(state);
    }
    getState() {
        return this.storageAPI.getState();
    }
    getTokenInfo() {
        const { token } = this.storageAPI.getState();
        if (!token) {
            return undefined;
        }
        try {
            return jwt_decode_1.default(token || '') || undefined;
        }
        catch (err) {
            return undefined;
        }
    }
    purgeState() {
        this.storageAPI.purgeState();
    }
    checkIsAuthorized() {
        const { token } = this.getState();
        return R.not(isEmptyOrNil(token));
    }
    login({ email, password }) {
        return __awaiter(this, void 0, void 0, function* () {
            const { userLogin } = yield this.graphQLClient.request(USER_LOGIN_MUTATION, {
                data: {
                    email,
                    password,
                    authProfileId: this.authProfileId,
                },
            });
            if (userLogin.success) {
                this.setState({
                    token: userLogin.auth.idToken,
                    refreshToken: userLogin.auth.refreshToken,
                });
            }
            return { success: userLogin.success || false };
        });
    }
    refreshToken() {
        return __awaiter(this, void 0, void 0, function* () {
            const { refreshToken } = this.getState();
            const { userRefreshToken } = yield this.graphQLClient.request(REFRESH_TOKEN_MUTATION, {
                data: {
                    refreshToken,
                    authProfileId: this.authProfileId,
                },
            });
            this.setState({
                token: userRefreshToken.idToken,
                refreshToken: userRefreshToken.refreshToken,
            });
        });
    }
    logout() {
        this.purgeState();
    }
}
exports.WebNativeAuthClient = WebNativeAuthClient;
//# sourceMappingURL=WebNativeAuthClient.js.map